%define anolis_release 2
# an audit.spec is provided in upstream audit source tree, modify to match
# Anolis OS specfile guidelines.

# Only support python3 in Anolis OS 23
%define __python python3

Name: audit
Version: 3.1.1
Release: %{anolis_release}%{dist}
Summary: User space tools for kernel auditing
License: GPL-2.0-or-later AND LGPL-2.0-or-later
Group: System Environment/Daemons

URL: https://people.redhat.com/sgrubb/audit/
Source0: https://people.redhat.com/sgrubb/audit/%{name}-%{version}.tar.gz
Patch1: audit-3.1.1-flex-array-workaround.patch
Patch2: audit-3.0.8-undo-flex-array.patch
Patch3: audit-3.1.1-prefix.patch
Patch4: audit-3.1.1-python3-linkage.patch


BuildRequires: gcc
BuildRequires: krb5-devel libcap-ng-devel
BuildRequires: kernel-headers >= 2.6.29
BuildRequires: systemd

Requires: %{name}-libs = %{version}-%{release}
%{?systemd_requires}

%description
The audit package contains the user space utilities for
storing and searching the audit records generated by
the audit subsystem in the Linux 2.6 and later kernels.

%package libs
Summary: Dynamic library for libaudit
# CAUTION: libs use another license.
License: LGPLv2+

%description libs
The audit-libs package contains the dynamic libraries needed for
applications to use the audit framework.

%package libs-devel
Summary: Header files for libaudit
License: LGPLv2+
Requires: %{name}-libs  = %{version}-%{release}
Requires: kernel-headers >= 2.6.29

%description libs-devel
The audit-libs-devel package contains the header files needed for
developing applications that need to use the audit framework libraries.

%package -n python3-audit
Summary: Python3 bindings for libaudit
License: LGPLv2+
BuildRequires: python3-devel swig
Requires: %{name}-libs = %{version}-%{release}
Provides: audit-libs-python3 = %{version}-%{release}
Obsoletes: audit-libs-python3 < %{version}-%{release}

%description -n python3-audit
The python3-audit package contains the bindings so that libaudit
and libauparse can be used by python3.

%package -n audispd-plugins
Summary: Plugins for the audit event dispatcher
License: GPLv2+
BuildRequires: krb5-devel libcap-ng-devel
Requires: %{name} = %{version}-%{release}
Requires: %{name}-libs = %{version}-%{release}

%description -n audispd-plugins
The audispd-plugins package provides plugins for the real-time
interface to the audit system, audispd. These plugins can do things
like relay events to remote machines or analyze events for suspicious
behavior.

%package -n audispd-plugins-zos
Summary: z/OS plugin for the audit event dispatcher
License: GPLv2+
BuildRequires: openldap-devel libcap-ng-devel
Requires: %{name} = %{version}-%{release}
Requires: %{name}-libs = %{version}-%{release}
 
%description -n audispd-plugins-zos
The audispd-plugins-zos package provides a plugin that will forward all
incoming audit events, as they happen, to a configured z/OS SMF (Service
Management Facility) database, through an IBM Tivoli Directory Server
(ITDS) set for Remote Audit service.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%setup -q
# FIXME part1: see https://listman.redhat.com/archives/linux-audit/2022-February/018843.html
cp -fv /usr/include/linux/audit.h lib/
%patch1 -p1
%patch3 -p1
%patch4 -p1

# Remove the ids code, upstream says it's not ready
sed -i 's/ ids / /' audisp/plugins/Makefile.am
sed -i 's/ ids / /' audisp/plugins/Makefile.in

%build
%configure \
	--disable-static \
        --with-python=no \
        --with-python3=yes  \
	--enable-gssapi-krb5=yes --with-arm --with-aarch64 \
	--with-libcap-ng=yes --without-golang --enable-zos-remote \
        --enable-systemd --enable-experimental --with-io_uring
%make_build

%install
mkdir --mode=0750 -p $RPM_BUILD_ROOT{%{_sysconfdir}/audit/plugins.d,%{_sysconfdir}/audit/rules.d}
mkdir --mode=0700 -p $RPM_BUILD_ROOT%{_var}/log/audit
mkdir -p $RPM_BUILD_ROOT%{_var}/spool/audit
%make_install

# On platforms with 32 & 64 bit libs, we need to coordinate the timestamp
touch -r ./audit.spec $RPM_BUILD_ROOT%{_sysconfdir}/libaudit.conf
touch -r ./audit.spec $RPM_BUILD_ROOT%{_mandir}/man5/libaudit.conf.5

# undo the workaround
pushd %{buildroot}
    patch -p0 < %{PATCH2}
    find . -name '*.orig' -delete
popd

%generate_compatibility_deps

%check
%make_build check
# Get rid of make files so that they don't get packaged.
rm -f rules/Makefile*

%post
# Copy default rules into place on new installation
files=`ls %{_sysconfdir}/audit/rules.d/ 2>/dev/null | wc -w`
if [ "$files" -eq 0 ] ; then
	cp %{_datadir}/%{name}/sample-rules/10-base-config.rules %{_sysconfdir}/audit/rules.d/audit.rules
	chmod 0600 %{_sysconfdir}/audit/rules.d/audit.rules
fi
%systemd_post auditd.service

%preun
%systemd_preun auditd.service

%postun
%systemd_postun auditd.service

%files libs
%dir %{abidir}
%license COPYING.LIB
%{_libdir}/libaudit.so.1*
%{_libdir}/libauparse.*
%{abidir}/_audit.dump
%{abidir}/libaudit.dump
%{abidir}/auparse.dump
%{abidir}/libauparse.dump
%config(noreplace) %{_sysconfdir}/libaudit.conf
%{_mandir}/man5/libaudit.conf.5.*

%files libs-devel
%doc contrib/plugin
%{_libdir}/libaudit.so
%{_libdir}/libauparse.so
%{_includedir}/libaudit.h
%{_includedir}/auparse.h
%{_includedir}/auparse-defs.h
%{_datadir}/aclocal/audit.m4
%{_libdir}/pkgconfig/audit.pc
%{_libdir}/pkgconfig/auparse.pc
%{_mandir}/man3/*

%files -n python3-audit
%attr(755,root,root) %{python3_sitearch}/*

%files
%license COPYING
%doc rules init.d/auditd.cron
%{_datadir}/%{name}/sample-rules/*
%{_mandir}/man8/auditctl.8*
%{_mandir}/man8/auditd.8*
%{_mandir}/man8/aureport.8*
%{_mandir}/man8/ausearch.8*
%{_mandir}/man8/autrace.8*
%{_mandir}/man8/aulast.8*
%{_mandir}/man8/aulastlog.8*
%{_mandir}/man8/auvirt.8*
%{_mandir}/man8/augenrules.8*
%{_mandir}/man8/ausyscall.8*
%{_mandir}/man8/audisp-af_unix.8*
%{_mandir}/man7/audit.rules.7*
%{_mandir}/man5/auditd.conf.5*
%{_mandir}/man5/ausearch-expression.5*
%{_mandir}/man5/auditd-plugins.5*
%{_sbindir}/auditctl
%{_sbindir}/auditd
%{_sbindir}/ausearch
%{_sbindir}/aureport
%{_sbindir}/autrace
%{_sbindir}/augenrules
%{_sbindir}/audisp-af_unix
%{_bindir}/aulast
%{_bindir}/aulastlog
%{_bindir}/ausyscall
%{_bindir}/auvirt
%{abidir}/ausearch-option.list
%{abidir}/aureport-option.list
%{abidir}/auvirt-option.list
%{_unitdir}/auditd.service
%dir %{_libexecdir}/initscripts/legacy-actions/auditd
%{_libexecdir}/initscripts/legacy-actions/auditd/condrestart
%{_libexecdir}/initscripts/legacy-actions/auditd/reload
%{_libexecdir}/initscripts/legacy-actions/auditd/restart
%{_libexecdir}/initscripts/legacy-actions/auditd/resume
%{_libexecdir}/initscripts/legacy-actions/auditd/rotate
%{_libexecdir}/initscripts/legacy-actions/auditd/state
%{_libexecdir}/initscripts/legacy-actions/auditd/stop
%{_libexecdir}/audit-functions
%ghost %{_localstatedir}/run/auditd.state
%attr(-,root,-) %dir %{_var}/log/audit
%dir %{_sysconfdir}/audit
%dir %{_sysconfdir}/audit/rules.d
%dir %{_sysconfdir}/audit/plugins.d
%config(noreplace) %attr(640,root,root) %{_sysconfdir}/audit/auditd.conf
%ghost %config(noreplace) %attr(640,root,root) %{_sysconfdir}/audit/rules.d/audit.rules
%ghost %config(noreplace) %attr(640,root,root) %{_sysconfdir}/audit/audit.rules
%config(noreplace) %attr(640,root,root) %{_sysconfdir}/audit/audit-stop.rules
%config(noreplace) %{_sysconfdir}/audit/plugins.d/af_unix.conf

%files -n audispd-plugins
%config(noreplace) %{_sysconfdir}/audit/audisp-remote.conf
%config(noreplace) %{_sysconfdir}/audit/plugins.d/au-remote.conf
%config(noreplace) %{_sysconfdir}/audit/plugins.d/syslog.conf
%config(noreplace) %{_sysconfdir}/audit/audisp-statsd.conf
%config(noreplace) %{_sysconfdir}/audit/plugins.d/au-statsd.conf
%attr(750,root,root) %{_sbindir}/audisp-remote
%attr(750,root,root) %{_sbindir}/audisp-syslog
%attr(750,root,root) %{_sbindir}/audisp-statsd
%{abidir}/audisp-remote-option.list
%attr(700,root,root) %dir %{_var}/spool/audit
%{_mandir}/man5/audisp-remote.conf.5*
%{_mandir}/man8/audisp-remote.8*
%{_mandir}/man8/audisp-syslog.8*
%{_mandir}/man8/audisp-statsd.8*

%files -n audispd-plugins-zos
%{_mandir}/man8/audispd-zos-remote.8*
%{_mandir}/man5/zos-remote.conf.5*
%config(noreplace) %{_sysconfdir}/audit/plugins.d/audispd-zos-remote.conf
%config(noreplace) %{_sysconfdir}/audit/zos-remote.conf
%attr(750,root,root) %{_sbindir}/audispd-zos-remote

%files doc
%doc README ChangeLog AUTHORS TODO NEWS

%changelog
* Mon May 29 2023 Funda Wang <fundawang@yeah.net> - 3.1.1-2
- Fix prefix inside systemd service

* Wed May 03 2023 Funda Wang <fundawang@yeah.net> - 3.1.1-1
- New version 3.1.1

* Thu Feb 16 2023 Funda Wang <fundawang@yeah.net> - 3.1-1
- New version 3.1

* Mon Dec 26 2022 yuanhui <yuanhui@linux.alibaba.com> - 3.0.9-1
- Update version to 3.0.9
- Add doc package

* Wed Nov 02 2022 mgb01105731 <mgb01105731@alibaba-inc.com> 3.0.7-4
- optimise spec file

* Wed Mar 16 2022 Caspar Zhang <caspar@linux.alibaba.com> 3.0.7-3
- Also provide compatible name audit-libs-python3

* Wed Mar 16 2022 Caspar Zhang <caspar@linux.alibaba.com> 3.0.7-2
- Apply flex array workaround from upstream

* Fri Mar 11 2022 Caspar Zhang <caspar@linux.alibaba.com> 3.0.7-1
- New upstream release for Anolis OS 23
